@@ -4,11 +4,13 @@ use strict; use warnings;
 
 package Time::Out;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Exporter                    qw( import );
-use Time::Out::ParamConstraints qw( assert_non_negative_number assert_plain_coderef );
-use Try::Tiny                   qw( try catch );
+use Scalar::Util                qw( blessed reftype );
+use Time::Out::Exception        qw();
+use Time::Out::ParamConstraints qw( assert_non_negative_number assert_plain_coderef is_plain_coderef );
+use Try::Tiny                   qw( catch finally try );
 
 sub _timeout( $$@ );
 
@@ -28,7 +30,7 @@ sub timeout( $@ ) {
   my $code      = assert_plain_coderef pop;
   my @code_args = @_;
 
-  my $error_at;
+  my $exception;
   # in scalar context store the result in the first array element
   my @result;
 
@@ -56,9 +58,10 @@ sub timeout( $@ ) {
         : $code->( @code_args );                    # void context
       alarm 0;
     } catch {
-      $error_at = $_
-    };
-    alarm 0;
+      $exception = ( is_plain_coderef $_ and $_ eq $code ) ? Time::Out::Exception->new( previous_exception => $@ ) : $_;
+    } finally {
+      alarm 0;
+    }
   }
 
   my $elapsed_time = time() - $start_time;
@@ -72,17 +75,13 @@ sub timeout( $@ ) {
     kill 'ALRM', $$;
   }
 
-  if ( $error_at ) {
-    if ( ( ref $error_at ) && ( $error_at eq $code ) ) {
-      $@ = 'timeout'; ## no critic (RequireLocalizedPunctuationVars)
-    } else {
-      if ( !ref $error_at ) {
-        chomp $error_at;
-        die "$error_at\n";
-      } else {
-        die $error_at; ## no critic (RequireCarping)
-      }
+  # handle exceptions
+  if ( defined $exception ) {
+    if ( defined blessed( $exception ) and $exception->isa( 'Time::Out::Exception' ) ) {
+      $@ = $exception; ## no  critic (RequireLocalizedPunctuationVars)
+      return;
     }
+    die $exception; ## no  critic (RequireCarping)
   }
 
   return
